
#  CA_EU_proposal.r
#
## ------------------------
# Catch allocation Based on the COASTAL proposal
# THis code follows the document 
# IOTC-2019-TCAC05-PropA[E] - Allocation of fishing opportunities.pdf 
#   
#
library(tidyr)
library(ggplot2)
library(dplyr)
# 

# Change the next line to reflect where the CA_Coastal_Prop folder is 
main_dir <- "C:/~~~YOUR FILE PATH HERE ~~~~~~~~~/CA_Coastal_Prop"
# e.g.
#  main_dir <- "C:/CA_Coastal_Prop"

#---------------------locate and create other file folders
setwd(main_dir)
data_dir <- paste0(main_dir, '/Data')
#------------load data
  load(   file=paste0(data_dir, '/G21_SimulationSpecs.Rdata'), verbose = TRUE  ) # simSPecs
   
  load(   file= paste0(data_dir, '/G21_Appendix1Table.rdata'), verbose = TRUE ) #   IOTC_data
 
  baselineDATA_Final <- read.csv(  file=paste0(data_dir, '/CoastalStates_baselinesABC2_Catches_v3_2019-02-05_1223.CSV'), header=TRUE, stringsAsFactors = FALSE)
  
#------------make results folder
results_dir <-    paste0(main_dir, '/Results')  
 dir.create(results_dir)
 
# Source the function for making catch allocations
 source(paste0(main_dir, "/make_coastal_allo_FUN.r"))
#------------------------------------------------------------------------------------------------------------------------------------
#------------------------------------------------------------------------------------------------------------------------------------
#------------------------------------------------------------------------------------------------------------------------------------
# #--------------------------------------------------------------------------------------------------------------------------------------
# 
# Make the historical allocation method clear to read 
bdat_A<-  gather(baselineDATA_Final,  "HA_method", "HA_prop", 3:5)
bdat_A$HA_method[bdat_A$HA_method=="p_contrib1" ] <- "5_year"
bdat_A$HA_method[bdat_A$HA_method=="p_contrib2" ] <- "15_year"
bdat_A$HA_method[bdat_A$HA_method=="p_contrib3" ] <- "Top_5"
#


#NumSims <- 100

NumSims <- nrow(simSpecs)
#
CoastSt_sims<- make_COASTAL_allocation(  simulation_spec =simSpecs[1, ] , baselineDATA=baselineDATA_Final, IOTC_data = IOTC_data)
head(CoastSt_sims)

CoastSt_sims%>% group_by(SPECIES_CODE)%>% summarise(allo = sum(Country_Prop)) # needs to be 3 across the board
#
start_time <- Sys.time()
for(i in 2:NumSims){ 
  CoastSt_sims<-cbind( CoastSt_sims,  make_COASTAL_allocation(  simulation_spec =simSpecs[i, ] , baselineDATA=baselineDATA_Final, IOTC_data = IOTC_data)[,"Country_Prop"] )
 #if(i %in% 1000*1:5) cat("\n Another 1000 done")
}
 colnames(CoastSt_sims ) <-c("flag", "SPECIES_CODE", "method" ,paste0("Sim_", seq(1:i)) ) 

 end_time <- Sys.time()
 el.time<-  end_time - start_time
 CoastSt_sims[1:4,1:5]
 dim(CoastSt_sims)
 
 CoastSt_sims <- cbind(HA_method=bdat_A$HA_method , CoastSt_sims)
# CoastSt_sims[1:4,1:5]
 st=format(Sys.time(), "%Y-%m-%d_%H%M")
 
 CoastSt_sims <- CoastSt_sims[,-4]
 colnames(CoastSt_sims ) <-c("HA_method", "flag", "SPECIES_CODE",  paste0("Sim_", seq(1:i)) ) 
 
 
 save( CoastSt_sims, file=  paste0(results_dir, "/CoastalStates_sims_",st, ".Rdata"  ) )

# write.csv( CoastSt_sims, file= "C:/Users/JSR/Dropbox/JoelWork/IOTC_2015/CatchAllocation/2. Data/G21_Results/CoastSt_sims_2019-01-04_0049.CSV", row.names = FALSE)
 write.csv( CoastSt_sims, file= paste0(results_dir, "/CoastalStates_sims_",st, ".csv" ), row.names=FALSE )  
 # 
 #
 colnames(baselineDATA_Final) <- c("flag", "SPECIES_CODE", "5_year", "15_year", "Top_5")
 write.csv( baselineDATA_Final, file= paste0(results_dir, "/CoastalStates_BaselineProportions_",st, ".csv" ), row.names=FALSE )  
 
 
 cat(NumSims, ' took ', el.time , 'mins')
 el.time 
 
 